@@ -19,9 +19,9 @@ function(clsize,ncategories,lin.pred,cor.matrix)
      stop("'cor.matrix' must be numeric")
  cor.matrix <- as.matrix(cor.matrix)
  if(ncol(cor.matrix)!=dims.lp) 
-    stop("'cor.matrix' must be ",dims.lp,"x",dims.lp," matrix")
+    stop("'cor.matrix' must be a ",dims.lp,"x",dims.lp," matrix")
  if(!isSymmetric(cor.matrix))
-     stop("'cor.matrix' must be symmetric")
+     stop("'cor.matrix' must be a symmetric matrix")
  for(i in 1:clsize){
  diag.index <- 1:ncategories+(i-1)*ncategories
  cor.matrix[diag.index,diag.index]<- diag(1,ncategories)
@@ -29,7 +29,7 @@ function(clsize,ncategories,lin.pred,cor.matrix)
  if(any(cor.matrix>1) | any(cor.matrix< -1))
      stop("all the elements of 'cor.matrix' must be on [-1,1]")
  if(any(eigen(cor.matrix,symmetric=TRUE,only.values=TRUE)$values<=0))
-     stop("'cor.matrix' must respect the local independence of the alternatives and be positive definite")
+     stop("'cor.matrix' must respect the local independence of the alternatives and it must be a positive definite matrix")
  err <- rnorta(R,cor.matrix=cor.matrix,distr="extreme")
  U <- lin.pred + err
  U <- matrix(as.vector(t(U)),nrow=clsize*R,ncol=ncategories,TRUE)
